/*                              FILE  INTERPO.PH
**
**                  INTERPOLATION FUNCTIONS AND DEFINITIONS
** ---------------------------------------------------------------------------
*/
#if defined(MTF)
   #define DINTERP  /* Define iff you will have need to differentiate */
#endif              /*    interpolated data.  Typically would not     */
                    /*    include to save memory.                     */

#if !defined(FILE)
   #error("FILE must be defined (eg by including stdio.h) to use interpolation functions.")
#endif

#if defined(MTF)
   #define INTEMAX 130
#else
   #define INTEMAX 60
#endif
                /* maximum number of interpolation points */
        /*  Note that some CVD and Ratheon index data sheets have 58 data 
        **  points. It makes no sense to through away this extra data if we 
        **  don't have to. We may not mave memory available in the TFD 
        **  program, however.  In this case, some points may be selectively 
        **  skipped by putting a * on the first line. 
        */

struct interp
   {
   triplet *mp;         /* pointer to last (max) datum      */
   triplet *lp;         /* pointer to latest datum accessed */
   triplet bp[INTEMAX]; /* base pointer to data             */
   };

int     interead(struct interp *, FILE *);    /* read interp data from file */
int     intechkord(struct interp *, int);     /* check order of interp data */
void    inteorder(struct interp *);           /* order interpolation data   */
int     intederiv2(struct interp *);          /* calculate 2nd derivatives  */
extrema interange(struct interp *idap);       /* return range               */
bool    is_intedomain(struct interp *, double, double);    /* check domain  */
double  interpolate(struct interp *, double); /* interpolate a point        */
#if defined(DINTERP)
   double dinterp(struct interp *, double);   /* find dy/dx of interpolated */
                                              /*    function.               */
#endif

