/*                               FILE  MATH.PH
**
**                   GENERAL MATH FUNCTIONS AND DEFINITIONS
**
**  RELATED FILES:
**     Some of the following used to be included in this file.
**     They have been separated out to save compile time and memory.
**     Errors may result in old code that still expects to find them here.
**  
**     COMPLEX .PH
**     INTEGRAL.PH
**     INTERPO .PH
**     RMATRIX .PH
**     OPTIMIZE.PH
**     GRAPHICS.PH
**
**  NOTE:
**     If math.ph is to be included, it should be included before
**     any of the related files since they may draw on its definitions.
** ----------------------------------------------------------------------------
**
**                                  SWITCHES
**
**  The following constants affect defines in this file only.
**  The are undefined at the bottom.
*/
#define  FLOCEIL  1   /* Determines whether floor or ceil or neither */
                      /* is simulated by the other.                  */
#define  FNLOG10  0   /* 0 -> log10 NOT loaded (simulated by log).   */


/*                                 CONSTANTS
**  
**  All double constants are defined in this section so as to be easily located
**  when writing the MATCONS check program.
**
**  1.79769e308 is the machine limit for type double.  The negative limit seems
**  to be the negative of this number; see program DBLRANGE in LEARN 
**  subdirectory.  At present MAXDBL is defined sligtly less than this.  This
**  is so that any number less than MAXDBL (in absolute value can be taken 
**  literally.  MAXDBL itself represents infinity, while values greater than 
**  MAXDBL represent other special conditions (e.g. error).
**
**  You do not need to remember the exact value of "infinity".  + or - MAXDBL
**  may be entered into any type double _LWIO field using Alt + and Alt - 
**  respectively, as defined by K_INFINITY and K_NEGINF in KEYS.PH.
*/
#define ERRDBL -1.79769e308  /* Error flag for functions returning double. */
#define MAXDBL  1.79767e308  /* Extreme "acceptable" value of type double. */

#define LN10  2.302585092994046  /* natural log of 10 */

#define PI12  1.570796326794897  /* (1/2)PI */
#define PI    3.141592653589793
#define PI2   6.283185307179586  /*    2 PI */
#define D2R   0.0174532925199433 /* degrees to radians|  These are not put in */
#define R2D  57.29577951308232   /* radians to degrees|  function form due to */
                                 /*        the new way C handles parentheses. */


/*                              TYPE DEFINITIONS
*/
typedef struct    /* The following comments give the significance of each */
                  /* struct member as used by the functions in _INTERPO.C */
                  /* triplet is defined in this header since it is used   */
   {              /* in various modules.                                  */
   double x,  /* Independent variable                       */
          y,  /* Known data corresponding to x              */
          z;  /* Second derivative calculated by intederiv2 */
   } triplet;

typedef struct
   {
   double min, max;
   } extrema;


/*                     GENERAL DEFINITIONS AND FUNCTIONS
**
**  pair and complex types defined in std.ph
*/
#define EXP10(X) exp(LN10*(X))      /* exponentential base 10 */

#if FNLOG10                         /* common log             */
   double cdecl log10(double);
   #define LOG10(X) log10(X);
#else
   #define LOG10(X) (log(X)/LN10)
#endif

#if FLOCEIL == 1                       /*    Try changing the FLOCEIL define  */
   double cdecl floor(double);         /* to see what generates the smallest  */
   #define FLOOR(X)  floor((X)+0.001)  /* code for a given application.       */
   #define CEIL(X)   floor((X)+0.999)  /*    ceil and floor declarations are  */
#elif FLOCEIL == 2                     /* commented out of math.h so that     */
   double cdecl ceil(double);          /* applications that use them contrary */
   #define FLOOR(X)  ceil((X)-0.999)   /* to the current FLOCEIL will have    */
   #define CEIL(X)   ceil((X)-0.001)   /* compile time errors.                */
#else                                  /*    Note that if X is an integer to  */
   double cdecl floor(double);         /* better that 3 decimals, FLOOR(X) =  */
   double cdecl ceil(double);          /* CEIL(X) ~ X.  The small number of   */
   #define FLOOR(X)  floor((X)+0.001)  /* places is for apps such as graphics */
   #define CEIL(X)   ceil((X) -0.001)  /* which need to calc floor and ceil   */
#endif                                 /* numbers which may be large and may  */
                                       /* already be "integers" which should  */
                                       /* be preserved.                       */


/*                                  SWITCHES
*/
#undef  FLOCEIL
#undef  FNLOG10
