/*                                   STD.PH
**
**                            STANDARD DEFINITIONS
**
**    Standard source code markers are explained in STDPH.DOC.  See that file
**    for that and other documentation which used to be printed in this file.
** ---------------------------------------------------------------------------
*/

/*                         COMPILATION CONTROL FLAGS
*/
/* #define SAVEROOM      /* Define to eliminate "nonessential" code in     */
                         /*    large, space critical, applications         */

/* #define COMPLEX       /* Define when complex I/O will be used.          */

#define WIND             /* Enable window routines in modules where this   */
                         /*   an option.  _LWIO.C or other window module   */
                         /*   must be linked.                              */

#if defined(DBG)         /* DBG defined on the command line when debugging.*/
   #undef SAVEROOM       /* in case it was defined on the command line.    */
   #define SAVEROOM
#endif

#if !defined(_QC)        /* _QC is defined when QC or QCL is used.         */
   #define _MSC          /* Defining and using _MSC leaves us open to      */
                         /* future compilers with as yet unknown features. */
   #if !defined(DBG)
      #pragma function(memset, memcpy, memcmp)
   #endif                /* If compiled with /Oi, we wish to exclude these */
                         /* fns due to warnings on p. 94 of v5.0 manual    */
#endif                   /* /Oi should NOT be used with DBG on             */


/*                          TYPE AND KEY DEFINITIONS
**  
**  Check similar window data type constant definitions
**  in LWIO.PH when any of these are changed.
*/
#define real    float          /* Comment out if not used.  See "real      */
                               /*    TYPE" documentation in STDPH.DOC      */
#define uchar   unsigned char
#define ushort  unsigned short /* Used by _LWIO.C for 2 char input &&&     */
#define ulong   unsigned long  /* Used by _LWIO.C for 2 char input &&&     */
#define uint    unsigned int
#define sint    int            /* Use for ints that can be either signed   */
                               /*    or unsigned. If change sint to uint   */
                               /*    must also change sint_ in LWIO.PH     */
#define bool    unsigned char  /* To make bool compatible with byte        */
#define word    unsigned int
#define byte    unsigned char

#define asmlib  cdecl          /* See "CALLING CONVENTIONS" in STDPH.DOC.  */ 

#define intern(rettype)  static rettype near pascal
#define interna(rettype) static rettype
                               /* See "INTERNAL FUNCTIONS" in STDPH.DOC    */

#define  ABORT       0x011B    /* Esc key */


/*                 See "PAIR AND COMPLEX TYPES" in STDPH.DOC
**
**   Comments below show differences between Microsoft's original definition 
**   and the current one. 
*/
#if !defined(NOFLOAT)
   typedef struct {    /* Removed complex structure tag and added typedef. */
       double  x, y;
       } pair;         /* Added pair identifier.                           */ 

   #define complex pair
#endif
/*                          END OF FILE STD.PH
******************************************************************************/

